## Copyright (C) 2009 Carlo de Falco <carlo DOT defalco AT gmail DOT com>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; If not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
##  @deftypefn {Function File} {@var{f} =}  __stepfunction__ (@var{t}, @var{t0}, @var{low}, @var{high})
##
## Undocumented internal function.
## @end deftypefn

function f = __stepfunction__ (t, t0, low, high)
  before = find (t<= t0);
  after  = find (t > t0);
  f = zeros (size (t));
  f(before) = low;
  f(after)  = high;
endfunction